/*
 * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifndef MANAGE_PRESETS_WINDOW_H
#define MANAGE_PRESETS_WINDOW_H
#include <gtk/gtk.h>
#include "gloo/gloo-presets.h"

G_BEGIN_DECLS

GtkWidget *
manage_presets_window_new (GlooPresets *gloo_presets);
void
manage_presets_window_open (GtkDialog *manage_presets_window);

G_END_DECLS

#endif /* MANAGE_PRESETS_WINDOW_H */
